use crate::SigType;
use serde::Deserialize;
use std::fs;

pub struct Config {
	pub(crate) port: String,
	pub(crate) pin: SigType,
}

impl std::convert::From<ConfigFile> for Config {
	fn from(c: ConfigFile) -> Self {
		let pin = match c.pin.to_lowercase().as_ref() {
			"dtr" => SigType::Dtr,
			"rts" => SigType::Rts,
			_ => panic!("Pin must be 'dtr' or 'rts'"),
		};

		Self { port: c.port, pin }
	}
}

#[derive(Deserialize)]
struct ConfigFile {
	port: String,
	pin: String,
}

pub fn get_conf() -> Config {
	let file_contents = read_conf_file();
	let config: ConfigFile = match toml::from_str(&file_contents) {
		Ok(x) => x,
		Err(x) => {
			panic!("Error parsing config file: {}", x);
		}
	};

	config.into()
}
fn read_conf_file() -> String {
	let filenames = ["config.toml"];
	for filename in filenames.iter() {
		if let Ok(x) = fs::read_to_string(filename) {
			return x;
		}
	}
	panic!("Could not open config file");
}
